summaryrefslogtreecommitdiff
path: root/src/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/config.h')
-rw-r--r--src/config.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/config.h b/src/config.h
index 7f48a70..d545531 100644
--- a/src/config.h
+++ b/src/config.h
@@ -61,9 +61,10 @@ typedef enum
/* ---------------------------------------- INTERFACES
*/
-/* Loads in config file. Returns FALSE for problems.
+/* Loads in config file (the default name if path is NULL). Returns FALSE
+ for problems.
*/
-int ConfigLoad(void);
+int ConfigLoad(const char *path);
/* Returns a reason for config load failure